epubgrep
========

Simple tool to search through EPub files.

All issues, questions, complaints, or (even better!) patches
should be send via email to
[~mcepl/devel@lists.sr.ht](mailto:~mcepl/devel@lists.sr.ht) email
list (for patches use [git
send-email](https://git-send-email.io/)).
